#
# spec file for package libgtpnl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgtpnl
Version:        1.2.5
Release:        1.3
Summary:        GPRS tunnel configuration library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://osmocom.org/projects/linux-kernel-gtp-u/wiki

Source:         https://github.com/osmocom/libgtpnl/archive/%version.tar.gz
BuildRequires:  libtool >= 2
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libmnl) >= 1.0.0

%description
libgtpnl wraps the genetlink-based GPRS tunnel configuration of the
Linux kernel into a C API.

%package -n libgtpnl0
Summary:        GPRS tunnel configuration library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libgtpnl0
libgtpnl wraps the genetlink-based GPRS tunnel configuration of the
Linux kernel into a C API.

%package devel
Summary:        Development files for the GPRS tunnel config library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       libgtpnl0 = %version

%description devel
libgtpnl wraps the genetlink-based GPRS tunnel configuration of the
Linux kernel into a C API.

This subpackage contains libraries and header files for developing
applications that want to make use of libgtpnl.

%package tools
Summary:        GTP tunnel configuration utilities
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Networking/Routing

%description tools
Utilities to configure GTP tunnels.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fi
# bugzilla.opensuse.org/795968 for rationale
%configure --includedir="%_includedir/%name"
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
%make_build check

%post   -n libgtpnl0 -p /sbin/ldconfig
%postun -n libgtpnl0 -p /sbin/ldconfig

%files -n libgtpnl0
%_libdir/libgtpnl.so.0*

%files devel
%license COPYING
%_includedir/libgtpnl/
%_libdir/libgtpnl.so
%_libdir/pkgconfig/*.pc

%files tools
%_bindir/gtp-*

%changelog
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.5
  * fix memleak on del_tunnel() failure
* Sun Jul  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.4
  * Updates to the --help text
* Wed Aug  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.3
  * fix some cases of rc == 0 on error
* Sun Mar 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.2
  * install gtp-tunnel and gtp-link tools
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Remove old specfile constructs.
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.2.1
  * Build descriptions for other platforms were updated;
    no user-visible changes
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.2.0
  * Fix CTRL_ATTR_FAMILY_ID attribute size
* Thu Dec 28 2017 jengelh@inai.de
- Update to new upstream release 1.1.0
  * gtp: fix missing initialization of netns file descriptor
  * tools,gtp-genl: gtp-tunnel: fix wrong MS address
  * tools: gtp-tunnel: restore option parsing
  * tools: gtp-link: allow to delete links
  * tools: gtp-link: bind to GTP UDP sockets
  * Fix look-up of GTP tunnel by TEI
  * Add support for SGSN role via IFLA_GTP_ROLE
  * Add support for SGSN role via IFLA_GTP_ROLE
* Sat Apr 29 2017 jengelh@inai.de
- Initial package (version 1.0.1.7) for build.opensuse.org
